@@ -2,13 +2,9 @@ from __future__ import annotations
 
 import asyncio
 import sys
-from typing import (
-    Any,
-    AsyncGenerator,
-    Coroutine,
-    Generator,
-    cast,
-)
+from collections.abc import AsyncGenerator, Generator
+from types import CoroutineType, GeneratorType
+from typing import Any, cast
 
 import pytest
 
@@ -24,15 +20,9 @@ from anyio import (
 )
 from anyio.abc import TaskStatus
 
-pytestmark = pytest.mark.anyio
+from .conftest import asyncio_params
 
-
-if sys.version_info >= (3, 8):
-    get_coro = asyncio.Task.get_coro
-else:
-
-    def get_coro(self: asyncio.Task) -> Any:
-        return self._coro
+get_coro = asyncio.Task.get_coro
 
 
 def test_main_task_name(
@@ -72,7 +62,7 @@ def test_main_task_name(
 async def test_non_main_task_name(
     name_input: bytes | str | None, expected: str
 ) -> None:
-    async def non_main(*, task_status: TaskStatus) -> None:
+    async def non_main(*, task_status: TaskStatus[str | None]) -> None:
         task_status.started(anyio.get_current_task().name)
 
     async with anyio.create_task_group() as tg:
@@ -106,7 +96,7 @@ async def test_get_running_tasks() -> None:
     for task, expected_name in zip(task_infos, expected_names):
         assert task.parent_id == host_task.id
         assert task.name == expected_name
-        assert repr(task) == f"TaskInfo(id={task.id}, name={expected_name!r})"
+        assert repr(task).endswith(f"TaskInfo(id={task.id}, name={expected_name!r})")
 
 
 @pytest.mark.skipif(
@@ -121,10 +111,11 @@ def test_wait_generator_based_task_blocked(
 ) -> None:
     async def native_coro_part() -> None:
         await wait_all_tasks_blocked()
-        gen = cast(Generator, get_coro(gen_task))
+        gen = cast(GeneratorType, get_coro(gen_task))
         assert not gen.gi_running
-        coro = cast(Coroutine, gen.gi_yieldfrom)
+        coro = cast(CoroutineType, gen.gi_yieldfrom)
         assert coro.cr_code.co_name == "wait"
+
         event.set()
 
     @asyncio.coroutine  # type: ignore[attr-defined]
@@ -136,7 +127,7 @@ def test_wait_generator_based_task_blocked(
     asyncio_event_loop.run_until_complete(native_coro_part())
 
 
-@pytest.mark.parametrize("anyio_backend", ["asyncio"])
+@pytest.mark.parametrize("anyio_backend", asyncio_params)
 async def test_wait_all_tasks_blocked_asend(anyio_backend: str) -> None:
     """Test that wait_all_tasks_blocked() does not crash on an `asend()` object."""
 
@@ -145,8 +136,8 @@ async def test_wait_all_tasks_blocked_asend(anyio_backend: str) -> None:
 
     agen = agen_func()
     coro = agen.asend(None)
-    loop = asyncio.get_event_loop()
-    task: asyncio.Task[None] = loop.create_task(coro)  # type: ignore[arg-type]
+    loop = asyncio.get_running_loop()
+    task = loop.create_task(cast("CoroutineType[Any, Any, Any]", coro))
     await wait_all_tasks_blocked()
     await task
     await agen.aclose()
